@@ -9,8 +9,8 @@ from .models import OrganizationPluginModel
 
 class OrganizationPlugin(CMSPluginBase):
     model = OrganizationPluginModel
-    name = _("Organization Plugin")
-    render_template = "multilingual_orgs/organization_plugin.html"
+    name = _('Organization Plugin')
+    render_template = 'multilingual_orgs/organization_plugin.html'
 
     def render(self, context, instance, placeholder):
         context.update({
