@@ -2,10 +2,12 @@
 import factory
 
 from django_libs.tests.factories import SimpleTranslationMixin
+from people.tests.factories import PersonFactory
 
 from ..models import (
     Organization,
     OrganizationPluginModel,
+    OrganizationPersonRole,
     OrganizationTranslation,
 )
 
@@ -31,6 +33,14 @@ class OrganizationFactory(SimpleTranslationMixin, factory.Factory):
         return (OrganizationTranslationFactory, 'organization')
 
 
+class OrganizationPersonRoleFactory(factory.Factory):
+    """Factory for the ``OrganizationPersonRole`` model."""
+    FACTORY_FOR = OrganizationPersonRole
+
+    organization = factory.SubFactory(OrganizationFactory)
+    person = factory.SubFactory(PersonFactory)
+
+
 class OrganizationPluginModelFactory(factory.Factory):
     """Factory for ``OrganizationPluginModel`` objects."""
     FACTORY_FOR = OrganizationPluginModel
